@@ -120,7 +120,8 @@ KRenameModel::KRenameModel( KRenameFile::List* vector )
       m_preview( false ),
       m_text( false ),
       m_maxDots( 0 ),
-      m_mimeType("text/uri-list")
+      m_mimeType("text/uri-list"),
+      m_eSortMode( eSortMode_Unsorted )
 {
 
 }
@@ -146,16 +147,39 @@ QVariant KRenameModel::data ( const QModelIndex & index, int role ) const
     if (index.row() >= m_vector->size())
         return QVariant();
 
-    if (role == Qt::DisplayRole && (!m_preview || (m_preview && m_text)) )
+    if (role == Qt::DisplayRole)
     {
-        return m_vector->at(index.row()).toString();
+        if (!m_preview) 
+        {
+            // Only return path
+            return m_vector->at(index.row()).toString();
+        }
+        else if (m_preview && m_text) 
+        {
+            // Short filename as first line in bold
+            // Path as second line
+            const KRenameFile & file = m_vector->at(index.row());
+            QString filename = file.srcFilename();
+            if (!file.srcExtension().isEmpty()) 
+            {
+                filename = filename + "." + file.srcExtension();
+            }
+
+            return "<qt><b>" + filename + "</b><br/>" +
+                file.toString() + "</qt>";
+        }
     }
     else if( role == Qt::DecorationRole && m_preview ) 
     {
         return m_vector->at(index.row()).icon();
     }
-    else
-        return QVariant();
+    else if( role == Qt::UserRole ) 
+    {
+        return m_vector->at(index.row()).toString();
+    }
+
+
+    return QVariant();
 }
 
 Qt::ItemFlags KRenameModel::flags(const QModelIndex &index) const
@@ -200,7 +224,7 @@ bool KRenameModel::dropMimeData(const QMimeData *data,
     {
         if( (*it).isValid() ) 
         {
-            KRenameFile file( *it );
+            KRenameFile file( *it, m_eSplitMode, m_dot );
 
             if( file.isValid() && !file.isDirectory() )
                 files.append( file );
@@ -289,7 +313,11 @@ void KRenameModel::addFiles( const KRenameFile::List & files )
 
         if( m_maxDots > oldMaxDots ) 
             emit maxDotsChanged( m_maxDots );
- 
+
+        // Update sorting
+        this->sortFiles( m_eSortMode );
+
+        // Generate previews if necessary
         if( m_preview ) 
         {
             // Construct a list of KFileItems
@@ -366,6 +394,8 @@ void KRenameModel::removeFiles( const QList<int> & remove )
 
 void KRenameModel::sortFiles( ESortMode mode )
 {
+    m_eSortMode = mode;
+
     if( mode == eSortMode_Ascending ) 
         qSort( m_vector->begin(), m_vector->end(), ascendingKRenameFileLessThan );
     else if( mode == eSortMode_Descending ) 
