@@ -20,6 +20,8 @@
 #include "krenamemodel.h"
 #include "plugin.h"
 #include "pluginloader.h"
+#include "richtextitemdelegate.h"
+#include "startupinfo.h"
 
 #include "ui_krenamefiles.h"
 #include "ui_krenamedestination.h"
@@ -44,13 +46,19 @@
 static const KRenameWindow::TGuiMode tAdvancedMode = {
     4,
     {
-        I18N_NOOP( "&Files" ),
-        I18N_NOOP( "&Destination" ),
-        I18N_NOOP( "&Plugins" ),
-        I18N_NOOP( "File&name" )
+        I18N_NOOP( "&1. Files" ),
+        I18N_NOOP( "&2. Destination" ),
+        I18N_NOOP( "&3. Plugins" ),
+        I18N_NOOP( "&4. Filename" )
     },
     {
         0, 1, 2, 3
+    },
+    {
+        "document-open-folder",
+        "document-save",
+        "configure",
+        "edit-rename"
     }
 };
 
@@ -62,6 +70,7 @@ KRenameWindow::KRenameWindow( QWidget* parent )
     QWidget*     center = new QWidget();
     QVBoxLayout* layout = new QVBoxLayout( center );
 
+    m_delegate = new RichTextItemDelegate(this);
     m_tabBar  = new QTabBar( center );
     m_stack   = new QStackedWidget( center );
     m_buttons = new QDialogButtonBox( center );
@@ -74,8 +83,10 @@ KRenameWindow::KRenameWindow( QWidget* parent )
 
     this->setCentralWidget( center );
 
-    for( int i=0;i<tAdvancedMode.numPages;i++ )
-        m_tabBar->addTab( i18n( tAdvancedMode.pageTitles[i] ) );
+    for( int i=0;i<tAdvancedMode.numPages;i++ ) {
+        const QIcon & icon = KIconLoader::global()->loadIcon( tAdvancedMode.pageIcons[i], KIconLoader::NoGroup, KIconLoader::SizeSmall );
+        m_tabBar->addTab( icon, i18n( tAdvancedMode.pageTitles[i] ) );
+    }
 
     m_pageFiles    = new Ui::KRenameFiles();
     m_pageDests    = new Ui::KRenameDestination();
@@ -106,8 +117,14 @@ KRenameWindow::KRenameWindow( QWidget* parent )
     setupPlugins();
     setupIcons();
 
+    StartUpInfo* startUp = new StartUpInfo();
+    connect( startUp, SIGNAL(addFiles()), SIGNAL(addFiles()));
+    connect( startUp, SIGNAL(enterTemplate()), SLOT(slotGotoTemplatesPage()));
+
     m_pageDests->urlrequester->setMode( KFile::Directory | KFile::ExistingOnly );
-    
+    m_pageFiles->fileList->setItemDelegate( m_delegate );
+    m_pageFiles->fileList->setInfoWidget( startUp );
+
     // Make sure that now signal occurs before setupGui was called
     connect( m_tabBar, SIGNAL(currentChanged(int)), SLOT(showPage(int)));
     connect( m_buttonClose, SIGNAL(clicked(bool)), SLOT(close()));
@@ -129,15 +146,45 @@ void KRenameWindow::loadConfig()
     // ExtHistoryCombo needs an object name
     m_pageFilename->filenameTemplate->setObjectName("FILENAME_TEMPLATE");
     m_pageFilename->extensionTemplate->setObjectName("EXTENSION_TEMPLATE");
+    m_pageFilename->comboFilenameCustom->setObjectName("FILENAME_CUSTOM_TEMPLATE");
+    m_pageFilename->comboExtensionCustom->setObjectName("EXTENSION_CUSTOM_TEMPLATE");
+    m_pageFilename->comboPrefixCustom->setObjectName("PREVIX_CUSTOM_TEMPLATE");
+    m_pageFilename->comboSuffixCustom->setObjectName("SUFFIX_CUSTOM_TEMPLATE");
+
 
     m_pageFilename->filenameTemplate->loadConfig();
     m_pageFilename->extensionTemplate->loadConfig();
+    m_pageFilename->comboFilenameCustom->loadConfig();
+    m_pageFilename->comboExtensionCustom->loadConfig();
+    m_pageFilename->comboPrefixCustom->loadConfig();
+    m_pageFilename->comboSuffixCustom->loadConfig();
+
+    KSharedConfigPtr config = KGlobal::config();
+    KConfigGroup groupGui = config->group( QString("GUISettings") );
+
+    int width = groupGui.readEntry( "Column0", QVariant(this->previewColumnWidth( 0 )) ).toInt();
+    if( width > 0 )
+		this->setPreviewColumnWidth( 0, width );
+
+    width = groupGui.readEntry( "Column1", QVariant(this->previewColumnWidth( 1 )) ).toInt();
+    if( width > 0 )
+	    this->setPreviewColumnWidth( 1, width );
 }
 
 void KRenameWindow::saveConfig() 
 {
     m_pageFilename->filenameTemplate->saveConfig();
     m_pageFilename->extensionTemplate->saveConfig();
+    m_pageFilename->comboFilenameCustom->saveConfig();
+    m_pageFilename->comboExtensionCustom->saveConfig();
+    m_pageFilename->comboPrefixCustom->saveConfig();
+    m_pageFilename->comboSuffixCustom->saveConfig();
+
+    KSharedConfigPtr config = KGlobal::config();
+    KConfigGroup groupGui = config->group( QString("GUISettings") );
+
+    groupGui.writeEntry( "Column0", this->previewColumnWidth( 0 ) );
+    groupGui.writeEntry( "Column1", this->previewColumnWidth( 1 ) );
 }
 
 void KRenameWindow::setupGui()
@@ -348,6 +395,7 @@ void KRenameWindow::setCount( unsigned int count )
     m_fileCount = count;
     m_pageFiles->labelCount->setText( i18n("<b>Files:<b> %1", m_fileCount ) );
 
+    m_pageFiles->fileList->slotUpdateCount();
     this->slotEnableControls();
 }
 
@@ -533,6 +581,13 @@ void KRenameWindow::setAdvancedMode( bool bAdvanced )
 void KRenameWindow::showFilenameTab()
 {
     m_tabBar->setCurrentIndex( MAX_PAGES - 1 );
+    if(this->isAdvancedMode()) {
+        m_pageFilename->filenameTemplate->setFocus();
+        m_pageFilename->filenameTemplate->selectAll();
+    } else {
+        m_pageFilename->comboPrefixCustom->setFocus();
+        m_pageFilename->comboPrefixCustom->selectAll();
+    }
 }
 
 void KRenameWindow::setPrefixSuffixSimple( QComboBox* combo, QComboBox* comboCustom, const QString & templ ) 
@@ -649,6 +704,11 @@ void KRenameWindow::slotRenameModeChanged()
     this->slotEnableControls();
 }
 
+void KRenameWindow::slotGotoTemplatesPage()
+{
+    m_tabBar->setCurrentIndex(3);
+}
+
 void KRenameWindow::slotSimpleStartIndexChanged()
 {
     emit startIndexChanged( m_pageFilename->spinIndex->value() );
@@ -795,6 +855,29 @@ void KRenameWindow::slotTokenHelpRequestedWizard4()
     emit showTokenHelpDialog( m_pageFilename->comboExtensionCustom->lineEdit() );
 }
 
+void KRenameWindow::setExtensionSplitMode( ESplitMode splitMode, int dot )
+{
+    int index;
+    switch( splitMode ) 
+    {
+        default:
+        case eSplitMode_FirstDot:
+            index = 0;
+            break;
+        case eSplitMode_LastDot:
+            index = 1;
+            break;
+        case eSplitMode_NoExtension:
+            index = 2;
+            break;
+        case eSplitMode_CustomDot:
+            index = dot + 1;
+            break;
+    }
+
+    m_pageFilename->comboExtension->setCurrentIndex( index );
+}
+
 void KRenameWindow::slotExtensionSplitModeChanged( int index )
 {
     ESplitMode splitMode;
