@@ -21,13 +21,21 @@
 #include "plugin.h"
 
 #include "datetimeplugin.h"
+#include "dirsortplugin.h"
+#ifdef WITH_EXIV2
 #include "exiv2plugin.h"
+#endif // WITH_EXIV2
 #include "fileplugin.h"
 #include "increasecounterplugin.h"
 #include "permissionsplugin.h"
 #include "scriptplugin.h"
 #include "systemplugin.h"
-#include "taglibplugin.h"
+#ifdef WITH_TAGLIB 
+# include "taglibplugin.h"
+#endif // WITH_TAGLIB
+#ifdef WITH_PODOFO 
+# include "podofoplugin.h"
+#endif // WITH_TAGLIB
 #include "translitplugin.h"
 
 #include "../config-krename.h"
@@ -123,16 +131,23 @@ void PluginLoader::load()
 #ifndef _WIN32
     m_plugins.append( new DateTimePlugin( this ) );
 #endif // _WIN32
-#ifdef HAVE_EXIV2
+    m_plugins.append( new DirSortPlugin( this ) );
+#ifdef WITH_EXIV2
     m_plugins.append( new Exiv2Plugin( this ) );
-#endif // HAVE_EXIV2
+#endif // WITH_EXIV2
 	m_plugins.append( new IncreaseCounterPlugin( this ) );
 #ifndef _WIN32
 	m_plugins.append( new PermissionsPlugin( this ) );
 #endif // _WIN32
     m_plugins.append( new ScriptPlugin( this ) );
     m_plugins.append( new SystemPlugin( this ) );
+
+#ifdef WITH_TAGLIB 
     m_plugins.append( new TagLibPlugin( this ) );
+#endif // WITH_TAGLIB 
+#ifdef WITH_PODOFO 
+    m_plugins.append( new PodofoPlugin( this ) );
+#endif // WITH_TAGLIB
     m_plugins.append( new TranslitPlugin( this ) );
     //this->loadFilePlugins();
 
